@@ -30,6 +30,18 @@
 #include "diff_internal.h"
 #include "diff_debug.h"
 
+off_t
+diff_chunk_get_left_start_pos(const struct diff_chunk *c)
+{
+	return c->left_start->pos;
+}
+
+off_t
+diff_chunk_get_right_start_pos(const struct diff_chunk *c)
+{
+	return c->right_start->pos;
+}
+
 bool
 diff_chunk_context_empty(const struct diff_chunk_context *cc)
 {
@@ -225,7 +237,7 @@ output_unidiff_chunk(struct diff_output_info *outinfo, FILE *dest,
 		     const struct diff_input_info *info,
 		     const struct diff_result *result,
 		     bool print_header, bool show_function_prototypes,
-		     const struct diff_chunk_context *cc, unsigned int ncontext)
+		     const struct diff_chunk_context *cc)
 {
 	int rc, left_start, left_len, right_start, right_len;
 	off_t outoff = 0, *offp;
@@ -292,7 +304,7 @@ output_unidiff_chunk(struct diff_output_info *outinfo, FILE *dest,
 	if (show_function_prototypes) {
 		rc = diff_output_match_function_prototype(state->prototype,
 		    sizeof(state->prototype), &state->last_prototype_idx,
-		    result, cc, ncontext);
+		    result, cc);
 		if (rc)
 			return rc;
 	}
@@ -421,7 +433,7 @@ diff_output_unidiff_chunk(struct diff_output_info **output_info, FILE *dest,
 	}
 
 	return output_unidiff_chunk(outinfo, dest, state, info,
-	    result, false, show_function_prototypes, cc, 0);
+	    result, false, show_function_prototypes, cc);
 }
 
 int
@@ -574,7 +586,7 @@ diff_output_unidiff(struct diff_output_info **output_info,
 		      " print left %d-%d right %d-%d\n",
 		      cc.left.start, cc.left.end, cc.right.start, cc.right.end);
 		output_unidiff_chunk(outinfo, dest, state, info, result,
-		    true, show_function_prototypes, &cc, context_lines);
+		    true, show_function_prototypes, &cc);
 		cc = next;
 		debug("new unprinted chunk is left %d-%d right %d-%d\n",
 		      cc.left.start, cc.left.end, cc.right.start, cc.right.end);
@@ -582,7 +594,7 @@ diff_output_unidiff(struct diff_output_info **output_info,
 
 	if (!diff_chunk_context_empty(&cc))
 		output_unidiff_chunk(outinfo, dest, state, info, result,
-		    true, show_function_prototypes, &cc, context_lines);
+		    true, show_function_prototypes, &cc);
 	diff_output_unidiff_state_free(state);
 	return DIFF_RC_OK;
 }
