@@ -14,6 +14,8 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include "got_compat.h"
+
 #include <sys/types.h>
 #include <sys/queue.h>
 #include <sys/uio.h>
@@ -1101,7 +1103,7 @@ recv_packfile(struct imsg *imsg, int infd)
 
 		if (r == 0) {
 			/* Detect gotd(8) closing the pack pipe when done. */
-			err = got_poll_fd(packfd, POLLOUT, 1);
+			err = got_poll_fd(packfd, 0, 1);
 			if (err) {
 				if (err->code != GOT_ERR_EOF)
 					break;
@@ -1311,7 +1313,7 @@ serve_write(int infd, int outfd, int gotd_sock, const char *repo_path,
 		case GOTD_IMSG_ERROR:
 			err = gotd_imsg_recv_error(NULL, &imsg);
 			goto done;
-		case GOTD_IMSG_RECV_PACKFILE:
+		case GOTD_IMSG_PACKFILE_PIPE:
 			err = recv_packfile(&imsg, infd);
 			if (err) {
 				if (err->code != GOT_ERR_EOF)
